datasets: Extract datasets from a sites object.

datasetsR Documentation

Extract datasets from a sites object.

Description

If the sites object contains datasets, then the datasets will be returned. If the sites object does not contain datasets then the user can apply get_datasets() to the object.

Usage

datasets(object)

## S4 method for signature 'collunit'
datasets(object)

## S4 method for signature 'sites'
datasets(object)

## S4 method for signature 'site'
datasets(object)

Arguments

object

A sites object

Value

datasets object specific to the metadata contained in datasets


neotoma2 documentation built on April 24, 2026, 1:06 a.m.