get_manual: get_manual

View source: R/get_manual.R

get_manualR Documentation

get_manual

Description

Open up the Neotoma manual homepage.

Usage

get_manual()

Value

NULL side effect for opening browser with the manual

Author(s)

Simon Goring goring@wisc.edu

Examples

## Not run: 
# This call does not work from `source()` calls or in testing.
# interactive() just lets us know you are interacting with the console:
if (interactive()) {
 get_manual()
}

## End(Not run)

neotoma2 documentation built on April 24, 2026, 1:06 a.m.