get_speleothems: get_speleothems

View source: R/get_speleothems.R

get_speleothemsR Documentation

get_speleothems

Description

get_speleothems

Usage

get_speleothems(x = NA, ...)

## S3 method for class 'numeric'
get_speleothems(x, ...)

## S3 method for class 'sites'
get_speleothems(x, ...)

Arguments

x

A dataset ID or vector of dataset IDs

...

accepted arguments

Details

Experimental function: API and behavior may change. The get_speleothems() command wraps the Neotoma API (api.neotomadb.org) call for speleothems. The call itself uses a SQL query which accepts any one of the following parameters:

  • x The unique dataset ID (integer) in Neotoma. Can be passed as a vector of dataset IDs.

  • sites A sites R object.

Value

sites object with speleothem data

Author(s)

Socorro Dominguez dominguezvid@wisc.edu

Examples

## Not run: 
## Find speleothems by numeric datasetid:
speleo <- get_speleothems(c(2,5))

## End(Not run)

neotoma2 documentation built on April 24, 2026, 1:06 a.m.