pingNeotoma: pingNeotoma

View source: R/pingNeotoma.r

pingNeotomaR Documentation

pingNeotoma

Description

A quick function to test whether or not the Neotoma Database API is currently running.

Usage

pingNeotoma(server = "neotoma")

Arguments

server

One of localhost:PORT (where PORT is a valid numeric port), neotoma or dev.

Value

A valid HTTP status code or returns an error if a connection is refused.

Examples

## Not run: 
test_connection <- pingNeotoma("neotoma")

## End(Not run)

neotoma2 documentation built on April 24, 2026, 1:06 a.m.