Learn R Programming

neotoma2 (version 1.1.0)

samples,sites-method: samples

Description

Obtain all samples within a sites object

Usage

# S4 method for sites
samples(x, chronname = NULL)

Value

data.frame with sample records

Arguments

x

sites object

chronname

Optional character name of a chronology to report ages against. When NULL (default) the Neotoma default-chronology precedence is applied. If the named chronology is not present for a dataset, the default is used and a warning is issued.

Author

Socorro Dominguez [email protected]

Simon Goring [email protected]

Examples

Run this code
if (FALSE) {
# Get full data download from API and create a long table with samples data.
dw <- get_downloads(1)
pollen <- samples(dw)
}

Run the code above in your browser using DataLab