| pingNeotoma | R Documentation |
A quick function to test whether or not the Neotoma Database API is currently running.
pingNeotoma(server = "neotoma")
server |
One of |
A valid HTTP status code or returns an error if a connection is refused.
## Not run:
test_connection <- pingNeotoma("neotoma")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.