# S4 method for sites
samples(x, chronname = NULL)
Value
data.frame with sample records
Arguments
x
sites object
chronname
Optional character name of a chronology to report ages
against. When NULL (default) the Neotoma default-chronology precedence
is applied. If the named chronology is not present for a dataset, the
default is used and a warning is issued.